@@ -3,7 +3,7 @@ from http import HTTPStatus
 from pathlib import Path
 
 import jupyterlab as jupyterlab_module  # type: ignore
-from fastapi import APIRouter, Depends, Response
+from fastapi import Response
 from fastapi.responses import HTMLResponse
 from fastapi.staticfiles import StaticFiles
 from jupyverse_api.app import App
@@ -25,11 +25,14 @@ class _JupyterLab(JupyterLab):
         frontend_config: FrontendConfig,
         lab: Lab,
     ) -> None:
-        super().__init__(app)
+        super().__init__(app, auth)
 
-        router = APIRouter()
-        self.prefix_dir, federated_extensions = lab.init_router(router, "lab")
-        extensions_dir = self.prefix_dir / "share" / "jupyter" / "labextensions"
+        self.jupyterlab_config = jupyterlab_config
+        self.frontend_config = frontend_config
+        self.lab = lab
+        lab.redirect_after_root = "lab"
+
+        extensions_dir = lab.prefix_dir / "share" / "jupyter" / "labextensions"
         self.federated_extensions, self.disabled_extension = lab.get_federated_extensions(
             extensions_dir
         )
@@ -38,7 +41,7 @@ class _JupyterLab(JupyterLab):
         if jupyterlab_config.dev_mode:
             self.static_lab_dir = jupyterlab_dir / "dev_mode" / "static"
         else:
-            self.static_lab_dir = self.prefix_dir / "share" / "jupyter" / "lab" / "static"
+            self.static_lab_dir = lab.prefix_dir / "share" / "jupyter" / "lab" / "static"
 
         self.mount(
             "/static/lab",
@@ -46,64 +49,58 @@ class _JupyterLab(JupyterLab):
             name="static",
         )
 
-        @router.get("/lab")
-        async def get_lab(
-            user: User = Depends(auth.current_user()),
-        ):
-            return HTMLResponse(
-                self.get_index(
-                    "default",
-                    frontend_config.collaborative,
-                    jupyterlab_config.dev_mode,
-                    frontend_config.base_url,
-                )
+    async def get_lab(
+        self,
+        user: User,
+    ):
+        return HTMLResponse(
+            self.get_index(
+                "default",
+                self.frontend_config.collaborative,
+                self.jupyterlab_config.dev_mode,
+                self.frontend_config.base_url,
             )
-
-        @router.get("/lab/tree/{path:path}")
-        async def load_workspace(
-            path,
-        ):
-            return HTMLResponse(
-                self.get_index(
-                    "default",
-                    frontend_config.collaborative,
-                    jupyterlab_config.dev_mode,
-                    frontend_config.base_url,
-                )
-            )
-
-        @router.get("/lab/api/workspaces/{name}")
-        async def get_workspace_data(user: User = Depends(auth.current_user())):
-            if user:
-                return json.loads(user.workspace)
-            return {}
-
-        @router.put(
-            "/lab/api/workspaces/{name}",
-            status_code=204,
         )
-        async def set_workspace(
-            request: Request,
-            user: User = Depends(auth.current_user()),
-            user_update=Depends(auth.update_user),
-        ):
-            workspace = (await request.body()).decode("utf-8")
-            await user_update({"workspace": workspace})
-            return Response(status_code=HTTPStatus.NO_CONTENT.value)
 
-        @router.get("/lab/workspaces/{name}", response_class=HTMLResponse)
-        async def get_workspace(
-            name,
-            user: User = Depends(auth.current_user()),
-        ):
-            return self.get_index(
-                name,
-                frontend_config.collaborative,
-                jupyterlab_config.dev_mode,
-                frontend_config.base_url,
+    async def load_workspace(
+        self,
+        path,
+    ):
+        return HTMLResponse(
+            self.get_index(
+                "default",
+                self.frontend_config.collaborative,
+                self.jupyterlab_config.dev_mode,
+                self.frontend_config.base_url,
             )
+        )
 
-        self.include_router(router)
+    async def get_workspace_data(self, user: User):
+        if user:
+            return json.loads(user.workspace)
+        return {}
+
+    async def set_workspace(
+        self,
+        request: Request,
+        user: User,
+        user_update,
+    ):
+        workspace = (await request.body()).decode("utf-8")
+        await user_update({"workspace": workspace})
+        return Response(status_code=HTTPStatus.NO_CONTENT.value)
+
+    async def get_workspace(
+        self,
+        name,
+        user: User,
+    ):
+        return self.get_index(
+            name,
+            self.frontend_config.collaborative,
+            self.jupyterlab_config.dev_mode,
+            self.frontend_config.base_url,
+        )
 
     def get_index(self, workspace, collaborative, dev_mode, base_url="/"):
         for path in (self.static_lab_dir).glob("main.*.js"):
@@ -149,9 +146,11 @@ class _JupyterLab(JupyterLab):
             "quitButton": True,
             "settingsUrl": "/lab/api/settings",
             "store_id": 0,
-            "schemasDir": (self.prefix_dir / "share" / "jupyter" / "lab" / "schemas").as_posix(),
+            "schemasDir": (
+                self.lab.prefix_dir / "share" / "jupyter" / "lab" / "schemas"
+            ).as_posix(),
             "terminalsAvailable": True,
-            "themesDir": (self.prefix_dir / "share" / "jupyter" / "lab" / "themes").as_posix(),
+            "themesDir": (self.lab.prefix_dir / "share" / "jupyter" / "lab" / "themes").as_posix(),
             "themesUrl": "/lab/api/themes",
             "token": "4e2804532de366abc81e32ab0c6bf68a73716fafbdbb2098",
             "translationsApiUrl": "/lab/api/translations",
